@@ -3,13 +3,13 @@ package Disk::SmartTools;
 use Dev::Util::Syntax;
 use Dev::Util::Const;
 use Dev::Util::OS   qw(:all);
-use Dev::Util::File qw(dir_suffix_slash);
+use Dev::Util::File qw(file_readable dir_suffix_slash);
 
 use Exporter qw(import);
 use IPC::Cmd qw[can_run run];
 use YAML::PP;
 
-our $VERSION = version->declare("v3.3.5");
+our $VERSION = version->declare("v3.3.8");
 
 our @EXPORT_OK = qw(
     get_disk_prefix
@@ -242,9 +242,11 @@ sub smart_cmd_for {
 
 sub load_local_config {
     my $hostname         = shift || $EMPTY_STR;
-    my $filename         = dir_suffix_slash( $ENV{ HOME } ) . '.smarttoolrc.yml';
+    my $filename         = dir_suffix_slash( $ENV{ HOME } ) . '.smarttoolsrc.yml';
     my $local_config_ref = {};
 
+    if ( !file_readable($filename) ) { return undef; }
+
     my $ypp              = YAML::PP->new;
     my $host_configs_ref = $ypp->load_file($filename);
 
@@ -268,7 +270,7 @@ Disk::SmartTools - Provide tools to work with disks via S.M.A.R.T.
 
 =head1 VERSION
 
-Version v3.3.5
+Version v3.3.8
 
 =head1 SYNOPSIS
 
